test_suite

Macro test_suite 

macro_rules! test_suite {
    (for: $backend:expr) => { ... };
    (attr: $attr:meta, args: $args:tt, backend: $backend:expr) => { ... };
}
Create test suite for rexecutor backend.

For backend implementors, it is useful to include this are part of your test suites.

Example

use rexecutor::test_suite;
use rexecutor::backend::memory::InMemoryBackend;
test_suite!(for: InMemoryBackend::new());

If you using a different async test attribute you can configure the marco to use that instead. For example when using sqlx::test you could do the following:

use rexecutor::test_suite;
test_suite!(
    attr: sqlx::test,
    args: (pool: PgPool),
    backend: BackendImplementation::from_pool(pool).await.unwrap()
);